This object constitutes a specific deal that was struck a priori between a buyer and a seller. Its presence with the Pmp collection indicates that this impression is available under the terms of that deal. Refer to Section 7.3 for more details.
@type t() :: %OpenRtbEcto.V2.BidRequest.Deal{ at: term(), bidfloor: term(), bidfloorcur: term(), ext: term(), id: term(), wadomain: term(), wseat: term() }