This object provides information pertaining to the device through which the user is interacting. Device information includes its hardware, platform, location, and carrier data. The device can refer to a mobile handset, a desktop computer, set top box, or other digital device.
Summary
Types
@type t() :: %OpenRtbEcto.V2.BidRequest.Device{ carrier: term(), connectiontype: term(), devicetype: term(), didmd5: term(), didsha1: term(), dnt: term(), dpidmd5: term(), dpidsha1: term(), ext: term(), flashver: term(), geo: term(), geofetch: term(), h: term(), hwv: term(), ifa: term(), ip: term(), ipv6: term(), js: term(), langb: term(), language: term(), lmt: term(), macmd5: term(), macsha1: term(), make: term(), mccmnc: term(), model: term(), os: term(), osv: term(), ppi: term(), pxratio: term(), sua: term(), ua: term(), w: term() }