This object is the private marketplace container for direct deals between buyers and sellers that may pertain to this impression. The actual deals are represented as a collection of Deal objects. Refer to Section 7.3 for more details.
@type t() :: %OpenRtbEcto.V2.BidRequest.Pmp{ deals: term(), ext: term(), private_auction: term() }