This object describes the publisher of the media in which the ad will be displayed. The publisher is typically the seller in an OpenRTB transaction.
@type t() :: %OpenRtbEcto.V2.BidRequest.Publisher{ cat: term(), cattax: term(), domain: term(), ext: term(), id: term(), name: term() }