OpenRtbEcto.V2.BidResponse.Bid (OpenRtbEcto v0.1.2) View Source
A SeatBid object contains one or more Bid objects, each of which relates to a specific impression in the bid request via the impid attribute and constitutes an offer to buy that impression for a given price.
Link to this section Summary
Link to this section Types
Specs
t() :: %OpenRtbEcto.V2.BidResponse.Bid{
adid: term(),
adm: term(),
adomain: term(),
api: term(),
attr: term(),
bundle: term(),
burl: term(),
cat: term(),
cid: term(),
crid: term(),
dealid: term(),
exp: term(),
ext: term(),
h: term(),
hratio: term(),
id: term(),
impid: term(),
iurl: term(),
language: term(),
lurl: term(),
nurl: term(),
price: term(),
protocol: term(),
qagmediarating: term(),
tactic: term(),
w: term(),
wratio: term()
}