The Image object to be used for all image elements of the Native ad such as Icons, Main Image, etc.
@type t() :: %OpenRtbEcto.V2.Native.Request.Img{ ext: term(), h: term(), hmin: term(), id: term(), mimes: term(), type: term(), w: term(), wmin: term() }