Corresponds to the Image Object in the request. The Image object to be used for all image elements of the Native ad such as Icons, Main Image, etc.
@type t() :: %OpenRtbEcto.V2.Native.Response.Img{ ext: term(), h: term(), id: term(), type: term(), url: term(), w: term() }